﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ESRI.ArcGIS.esriSystem;
using ESRI.ArcGIS.Geodatabase;

namespace AddSHPFile
{
    public partial class Form1 : Form
    {
        // 0: None
        // 1: Zoom In Mode
        // 2: Zoom Out Mode
        // 3: Pan
        private int MapViewMode = 0;

        private bool bMouseDown = false;
        private ESRI.ArcGIS.Geometry.IPoint DownPt = new ESRI.ArcGIS.Geometry.Point();
//        private ESRI.ArcGIS.Geometry.IPoint UpPt = new ESRI.ArcGIS.Geometry.Point();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            AoInitialize pAoInitialize = new AoInitialize();

            //Try to initialize license
            try
            {
                if (pAoInitialize.IsProductCodeAvailable(esriLicenseProductCode.esriLicenseProductCodeArcInfo) 
                        == esriLicenseStatus.esriLicenseAvailable)               
                {
                    pAoInitialize.Initialize(esriLicenseProductCode.esriLicenseProductCodeArcInfo);
                }               
                else
                {
                    MessageBox.Show(
                        "ArcInfo license not available. Check your network connection.");               
                }       
            }       //Catch any errors
            catch (Exception exception) {
                MessageBox.Show("Error: " + exception);       
            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            ESRI.ArcGIS.Geodatabase.IWorkspaceFactory pWF;
            ESRI.ArcGIS.Geodatabase.IFeatureWorkspace pFW;
            ESRI.ArcGIS.Carto.IFeatureLayer pFL;

            pWF = new ESRI.ArcGIS.DataSourcesFile.ShapefileWorkspaceFactory();
            pFW = pWF.OpenFromFile("d:/__data__", 0) as ESRI.ArcGIS.Geodatabase.IFeatureWorkspace;
            pFL = new ESRI.ArcGIS.Carto.FeatureLayer();
            pFL.FeatureClass = pFW.OpenFeatureClass("seoul");
            pFL.Name = pFL.FeatureClass.AliasName;

            axMapControl1.AddLayer(pFL);
        }

        private void button2_Click(object sender, EventArgs e)
        {
            // 0: None
            // 1: Zoom In Mode
            // 2: Zoom Out Mode
            // 3: Pan
            MapViewMode = 1;
        }

        private void button3_Click(object sender, EventArgs e)
        {
            // 0: None
            // 1: Zoom In Mode
            // 2: Zoom Out Mode
            // 3: Pan
            MapViewMode = 2;
        }

        private void button4_Click(object sender, EventArgs e)
        {
            // 0: None
            // 1: Zoom In Mode
            // 2: Zoom Out Mode
            // 3: Pan
            MapViewMode = 3;
        }

        private void axMapControl1_OnMouseDown(object sender, AxESRI.ArcGIS.Controls.IMapControlEvents2_OnMouseDownEvent e)
        {
            bMouseDown = true;
            DownPt.X = e.mapX;
            DownPt.Y = e.mapY;

            if (MapViewMode == 1) 
            {
                ESRI.ArcGIS.Geometry.IEnvelope pEnv = axMapControl1.TrackRectangle();
                axMapControl1.ActiveView.Extent = pEnv;
                axMapControl1.ActiveView.Refresh();
            }
            else if(MapViewMode == 2) 
            {
                ESRI.ArcGIS.Geometry.IEnvelope pEnv = axMapControl1.TrackRectangle();
                
                double OldWidth = axMapControl1.ActiveView.Extent.XMax - axMapControl1.ActiveView.Extent.XMin;
                double TrackWidth = pEnv.XMax - pEnv.XMin;
                double RatioWidth = OldWidth / TrackWidth;
                double OldHeight = axMapControl1.ActiveView.Extent.YMax - axMapControl1.ActiveView.Extent.YMin;
                double TrackHeight = pEnv.YMax - pEnv.YMin;
                double RatioHeight = OldHeight / TrackHeight;

                ESRI.ArcGIS.Geometry.IEnvelope pNewEnv = new ESRI.ArcGIS.Geometry.EnvelopeClass();
                pNewEnv.XMin = axMapControl1.ActiveView.Extent.XMin - (RatioWidth - 1.0) * OldWidth;
                pNewEnv.XMax = axMapControl1.ActiveView.Extent.XMax + (RatioWidth - 1.0) * OldWidth;
                pNewEnv.YMin = axMapControl1.ActiveView.Extent.YMin - (RatioHeight - 1.0) * OldHeight;
                pNewEnv.YMax = axMapControl1.ActiveView.Extent.YMax + (RatioHeight - 1.0) * OldHeight;

                axMapControl1.ActiveView.Extent = pNewEnv;

                axMapControl1.ActiveView.Refresh();
            } 
            else if(MapViewMode == 3) 
            {
                ESRI.ArcGIS.Geometry.IPoint pPt = new ESRI.ArcGIS.Geometry.Point();
                pPt.X = e.mapX;
                pPt.Y = e.mapY;
                axMapControl1.ActiveView.ScreenDisplay.PanStart(pPt);
            }
        }

        private void axMapControl1_OnMouseUp(object sender, AxESRI.ArcGIS.Controls.IMapControlEvents2_OnMouseUpEvent e)
        {
            if (MapViewMode == 3 && bMouseDown)
            {
                ESRI.ArcGIS.Geometry.IEnvelope pEnv = axMapControl1.ActiveView.ScreenDisplay.PanStop();
                if(pEnv != null) 
                {
                    axMapControl1.ActiveView.Extent = pEnv;
                    axMapControl1.ActiveView.Refresh();
                }
            }

            bMouseDown = false;
        }

        private void button5_Click(object sender, EventArgs e)
        {
            axMapControl1.ActiveView.Extent = axMapControl1.ActiveView.FullExtent;
            axMapControl1.ActiveView.Refresh();
        }

        private void axMapControl1_OnMouseMove(object sender, AxESRI.ArcGIS.Controls.IMapControlEvents2_OnMouseMoveEvent e)
        {
            if(MapViewMode==3 && bMouseDown) 
            {
                ESRI.ArcGIS.Geometry.IPoint pPt = new ESRI.ArcGIS.Geometry.Point();
                pPt.X = e.mapX;
                pPt.Y = e.mapY;

                axMapControl1.ActiveView.ScreenDisplay.PanMoveTo(pPt);
            }
        }            
    }
}